/// <reference types="node" />
import { EventEmitter } from 'events';
import { LevelUp } from 'levelup';
import { Address } from 'web3x/address';
import { Log } from '../tx';
import { BlockHeader } from './block-header';
import { BlockState } from './block-state';
import { EvaluatedTx } from './evaluate-txs';
export interface BlockchainContext {
    blockNumber: number;
    last256BlockHashes: Buffer[];
    coinbase: Address;
    timestamp: number;
    difficulty: bigint;
    blockGasLimit: bigint;
}
export declare type GetLogsResult = {
    block: BlockHeader;
    blockHash: Buffer;
    transactionIndex: number;
    transactionHash: Buffer;
    log: Log;
}[];
export declare class Blockchain extends EventEmitter {
    db: LevelUp;
    private blockHeaders;
    private blockHashes;
    constructor(db: LevelUp, blockHeaders: BlockHeader[], blockHashes: Buffer[]);
    static fromDb(db: LevelUp): Promise<Blockchain>;
    private getNextBlockNumber;
    getContext(): BlockchainContext;
    addBlock(blockState: BlockState, evaluatedTxs: EvaluatedTx[]): Promise<void>;
    private addBlockToDb;
    getMinedTransaction(txHash: Buffer): Promise<{
        blockHash: Buffer;
        blockHeader: BlockHeader;
        tx: import("../tx").Tx;
        txIndex: number;
        from: Address;
    } | undefined>;
    getTransactionReceipt(txHash: Buffer): Promise<import("../tx").TxReceipt | null>;
    private indexKeyedTrieToArray;
    getLogs(addresses: Address[], topics: (Buffer[] | null)[], fromBlock: number, toBlock: number): Promise<{
        block: BlockHeader;
        blockHash: Buffer;
        transactionIndex: number;
        transactionHash: Buffer;
        log: Log;
    }[]>;
    getChaintip(): BlockHeader;
}
