/// <reference types="node" />
import { EventEmitter } from 'events';
import { LevelUp } from 'levelup';
import { EthereumProvider, EthereumProviderNotifications } from 'web3x/providers';
import { Wallet } from 'web3x/wallet';
import { Blockchain } from '../blockchain';
import { WorldState } from '../world';
export interface EvmProviderOptions {
    blockDelay?: number;
    wallet?: Wallet;
    listenForBlocks?: boolean;
}
export declare class EvmProvider extends EventEmitter implements EthereumProvider {
    readonly worldState: WorldState;
    private readonly blockchain;
    private options;
    wallet?: Wallet;
    private subscriptions;
    private nextSubscriptionId;
    private blockHandler;
    constructor(worldState: WorldState, blockchain: Blockchain, options?: EvmProviderOptions);
    static fromEvmProvider(provider: EvmProvider, options?: EvmProviderOptions): EvmProvider;
    static fromDb(db: LevelUp, options?: EvmProviderOptions): Promise<EvmProvider>;
    static fromLocalDb(name: string, options?: EvmProviderOptions): Promise<EvmProvider>;
    static eraseLocalDb(name: string): Promise<{}>;
    loadWallet(wallet: Wallet, amount?: bigint): Promise<void>;
    setBlockDelay(blockDelay: number): void;
    send(method: string, params?: any[] | undefined): Promise<any>;
    private subscribe;
    private unsubscribe;
    private handleLogs;
    private handleNewHead;
    private handleBlock;
    on(notification: 'notification', listener: (result: any) => void): this;
    on(notification: 'connect', listener: () => void): this;
    on(notification: 'close', listener: (code: number, reason: string) => void): this;
    on(notification: 'networkChanged', listener: (networkId: string) => void): this;
    on(notification: 'accountsChanged', listener: (accounts: string[]) => void): this;
    removeListener(notification: 'notification', listener: (result: any) => void): this;
    removeListener(notification: 'connect', listener: () => void): this;
    removeListener(notification: 'close', listener: (code: number, reason: string) => void): this;
    removeListener(notification: 'networkChanged', listener: (networkId: string) => void): this;
    removeListener(notification: 'accountsChanged', listener: (accounts: string[]) => void): this;
    removeAllListeners(notification: EthereumProviderNotifications): any;
    close(): void;
}
